<?php

namespace Drupal\batch_services;

/**
 * A service for the Batch API.
 */
interface BatchWorkerServiceInterface {

  /**
   * Sets the internal context array to the given array.
   *
   * @param array $context
   *   The batch context array.
   */
  public function setContext(array &$context);

  /**
   * Gets the page number based on the current id & number of items per page.
   *
   * @return int
   *   The page number.
   */
  public function getPageNumber() : int;

  /**
   * Method to handle processing of single batch item.
   */
  public function processBatchItem();

  /**
   * Method to handle successful batch processing.
   *
   * @param array $results
   *   The results array.
   * @param string $duration
   *   How long it took to process the batch.
   */
  public function batchProcessingFinished(array $results, $duration);

  /**
   * Method to handle failed batch processing.
   *
   * @param mixed $failure
   *   The operations item related to the failure.
   */
  public function batchProcessingFailed($failure);

  /**
   * Gets the batch title.
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   *   The title in the TranslatableMarkup object.
   */
  public function getTitle();

  /**
   * Gets the batch error message.
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   *   The error message in the TranslatableMarkup object.
   */
  public function getErrorMessage();

}
